# Nanoprobe
Set of tools to profile your shiny python code


## Disclaimer 

This project is currently being developed and documentation, test, examples and all that cool stuff everyone is doing are not available yet.

With that said, all the code that is already uploaded is documented as best as we possibly can.

Feel free to start using it, docs and a proper project structure will roll out over the next few days.

